=================
pybind11_generics
=================

generics library for pybind11

This library provides various C++ wrappers around python objects when wrapping using pybind11. The
only extra feature these classes have is that the generated documentation have the correct type hint
strings.
